@@ -13,6 +13,8 @@ from ...models.method_cd import MethodCD
 from ...models.method_cd_update import MethodCDUpdate
 from ...models.method_cpt import MethodCPT
 from ...models.method_cpt_update import MethodCPTUpdate
+from ...models.method_def import MethodDEF
+from ...models.method_def_update import MethodDEFUpdate
 from ...models.method_dp import MethodDP
 from ...models.method_dp_update import MethodDPUpdate
 from ...models.method_dt import MethodDT
@@ -41,20 +43,24 @@ from ...models.method_rws import MethodRWS
 from ...models.method_rws_update import MethodRWSUpdate
 from ...models.method_sa import MethodSA
 from ...models.method_sa_update import MethodSAUpdate
+from ...models.method_slb import MethodSLB
+from ...models.method_slb_update import MethodSLBUpdate
 from ...models.method_spt import MethodSPT
 from ...models.method_spt_update import MethodSPTUpdate
-from ...models.method_sr import MethodSR
-from ...models.method_sr_update import MethodSRUpdate
 from ...models.method_srs import MethodSRS
 from ...models.method_srs_update import MethodSRSUpdate
 from ...models.method_ss import MethodSS
 from ...models.method_ss_update import MethodSSUpdate
+from ...models.method_sti import MethodSTI
+from ...models.method_sti_update import MethodSTIUpdate
 from ...models.method_svt import MethodSVT
 from ...models.method_svt_update import MethodSVTUpdate
 from ...models.method_tot import MethodTOT
 from ...models.method_tot_update import MethodTOTUpdate
 from ...models.method_tp import MethodTP
 from ...models.method_tp_update import MethodTPUpdate
+from ...models.method_tr import MethodTR
+from ...models.method_tr_update import MethodTRUpdate
 from ...models.method_wst import MethodWST
 from ...models.method_wst_update import MethodWSTUpdate
 from ...types import Response
@@ -69,6 +75,7 @@ def _get_kwargs(
         "MethodADUpdate",
         "MethodCDUpdate",
         "MethodCPTUpdate",
+        "MethodDEFUpdate",
         "MethodDPUpdate",
         "MethodDTUpdate",
         "MethodESAUpdate",
@@ -83,13 +90,15 @@ def _get_kwargs(
         "MethodRSUpdate",
         "MethodRWSUpdate",
         "MethodSAUpdate",
+        "MethodSLBUpdate",
         "MethodSPTUpdate",
         "MethodSRSUpdate",
-        "MethodSRUpdate",
         "MethodSSUpdate",
+        "MethodSTIUpdate",
         "MethodSVTUpdate",
         "MethodTOTUpdate",
         "MethodTPUpdate",
+        "MethodTRUpdate",
         "MethodWSTUpdate",
     ],
 ) -> dict[str, Any]:
@@ -100,59 +109,64 @@ def _get_kwargs(
         "url": f"/projects/{project_id}/locations/{location_id}/methods/{method_id}",
     }
 
-    _body: dict[str, Any]
+    _kwargs["json"]: dict[str, Any]
     if isinstance(body, MethodCPTUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodTOTUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodRPUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodSAUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodPZUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodSSUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodRWSUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodRCDUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodRSUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodSVTUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodSPTUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodCDUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodTPUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodPTUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodESAUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
+    elif isinstance(body, MethodTRUpdate):
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodADUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodROUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodINCUpdate):
-        _body = body.to_dict()
-    elif isinstance(body, MethodSRUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
+    elif isinstance(body, MethodDEFUpdate):
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodIWUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodDTUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodOTHERUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodSRSUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
     elif isinstance(body, MethodDPUpdate):
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
+    elif isinstance(body, MethodWSTUpdate):
+        _kwargs["json"] = body.to_dict()
+    elif isinstance(body, MethodSLBUpdate):
+        _kwargs["json"] = body.to_dict()
     else:
-        _body = body.to_dict()
+        _kwargs["json"] = body.to_dict()
 
-    _kwargs["json"] = _body
     headers["Content-Type"] = "application/json"
 
     _kwargs["headers"] = headers
@@ -168,6 +182,7 @@ def _parse_response(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -182,13 +197,15 @@ def _parse_response(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -201,6 +218,7 @@ def _parse_response(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -215,13 +233,15 @@ def _parse_response(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ]:
             try:
@@ -347,7 +367,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_15 = MethodAD.from_dict(data)
+                response_200_type_15 = MethodTR.from_dict(data)
 
                 return response_200_type_15
             except:  # noqa: E722
@@ -355,7 +375,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_16 = MethodRO.from_dict(data)
+                response_200_type_16 = MethodAD.from_dict(data)
 
                 return response_200_type_16
             except:  # noqa: E722
@@ -363,7 +383,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_17 = MethodINC.from_dict(data)
+                response_200_type_17 = MethodRO.from_dict(data)
 
                 return response_200_type_17
             except:  # noqa: E722
@@ -371,7 +391,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_18 = MethodSR.from_dict(data)
+                response_200_type_18 = MethodINC.from_dict(data)
 
                 return response_200_type_18
             except:  # noqa: E722
@@ -379,7 +399,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_19 = MethodIW.from_dict(data)
+                response_200_type_19 = MethodDEF.from_dict(data)
 
                 return response_200_type_19
             except:  # noqa: E722
@@ -387,7 +407,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_20 = MethodDT.from_dict(data)
+                response_200_type_20 = MethodIW.from_dict(data)
 
                 return response_200_type_20
             except:  # noqa: E722
@@ -395,7 +415,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_21 = MethodOTHER.from_dict(data)
+                response_200_type_21 = MethodDT.from_dict(data)
 
                 return response_200_type_21
             except:  # noqa: E722
@@ -403,7 +423,7 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_22 = MethodSRS.from_dict(data)
+                response_200_type_22 = MethodOTHER.from_dict(data)
 
                 return response_200_type_22
             except:  # noqa: E722
@@ -411,24 +431,50 @@ def _parse_response(
             try:
                 if not isinstance(data, dict):
                     raise TypeError()
-                response_200_type_23 = MethodDP.from_dict(data)
+                response_200_type_23 = MethodSRS.from_dict(data)
 
                 return response_200_type_23
             except:  # noqa: E722
                 pass
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                response_200_type_24 = MethodDP.from_dict(data)
+
+                return response_200_type_24
+            except:  # noqa: E722
+                pass
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                response_200_type_25 = MethodWST.from_dict(data)
+
+                return response_200_type_25
+            except:  # noqa: E722
+                pass
+            try:
+                if not isinstance(data, dict):
+                    raise TypeError()
+                response_200_type_26 = MethodSLB.from_dict(data)
+
+                return response_200_type_26
+            except:  # noqa: E722
+                pass
             if not isinstance(data, dict):
                 raise TypeError()
-            response_200_type_24 = MethodWST.from_dict(data)
+            response_200_type_27 = MethodSTI.from_dict(data)
 
-            return response_200_type_24
+            return response_200_type_27
 
         response_200 = _parse_response_200(response.json())
 
         return response_200
+
     if response.status_code == 422:
         response_422 = HTTPValidationError.from_dict(response.json())
 
         return response_422
+
     if client.raise_on_unexpected_status:
         raise errors.UnexpectedStatus(response.status_code, response.content)
     else:
@@ -444,6 +490,7 @@ def _build_response(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -458,13 +505,15 @@ def _build_response(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -487,6 +536,7 @@ def sync_detailed(
         "MethodADUpdate",
         "MethodCDUpdate",
         "MethodCPTUpdate",
+        "MethodDEFUpdate",
         "MethodDPUpdate",
         "MethodDTUpdate",
         "MethodESAUpdate",
@@ -501,13 +551,15 @@ def sync_detailed(
         "MethodRSUpdate",
         "MethodRWSUpdate",
         "MethodSAUpdate",
+        "MethodSLBUpdate",
         "MethodSPTUpdate",
         "MethodSRSUpdate",
-        "MethodSRUpdate",
         "MethodSSUpdate",
+        "MethodSTIUpdate",
         "MethodSVTUpdate",
         "MethodTOTUpdate",
         "MethodTPUpdate",
+        "MethodTRUpdate",
         "MethodWSTUpdate",
     ],
 ) -> Response[
@@ -517,6 +569,7 @@ def sync_detailed(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -531,13 +584,15 @@ def sync_detailed(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -550,19 +605,20 @@ def sync_detailed(
         project_id (str):
         location_id (UUID):
         method_id (UUID):
-        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDPUpdate',
-            'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate', 'MethodIWUpdate',
-            'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate', 'MethodRCDUpdate',
-            'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate', 'MethodRWSUpdate', 'MethodSAUpdate',
-            'MethodSPTUpdate', 'MethodSRSUpdate', 'MethodSRUpdate', 'MethodSSUpdate',
-            'MethodSVTUpdate', 'MethodTOTUpdate', 'MethodTPUpdate', 'MethodWSTUpdate']):
+        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDEFUpdate',
+            'MethodDPUpdate', 'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate',
+            'MethodIWUpdate', 'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate',
+            'MethodRCDUpdate', 'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate',
+            'MethodRWSUpdate', 'MethodSAUpdate', 'MethodSLBUpdate', 'MethodSPTUpdate',
+            'MethodSRSUpdate', 'MethodSSUpdate', 'MethodSTIUpdate', 'MethodSVTUpdate',
+            'MethodTOTUpdate', 'MethodTPUpdate', 'MethodTRUpdate', 'MethodWSTUpdate']):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]]
+        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
     """
 
     kwargs = _get_kwargs(
@@ -589,6 +645,7 @@ def sync(
         "MethodADUpdate",
         "MethodCDUpdate",
         "MethodCPTUpdate",
+        "MethodDEFUpdate",
         "MethodDPUpdate",
         "MethodDTUpdate",
         "MethodESAUpdate",
@@ -603,13 +660,15 @@ def sync(
         "MethodRSUpdate",
         "MethodRWSUpdate",
         "MethodSAUpdate",
+        "MethodSLBUpdate",
         "MethodSPTUpdate",
         "MethodSRSUpdate",
-        "MethodSRUpdate",
         "MethodSSUpdate",
+        "MethodSTIUpdate",
         "MethodSVTUpdate",
         "MethodTOTUpdate",
         "MethodTPUpdate",
+        "MethodTRUpdate",
         "MethodWSTUpdate",
     ],
 ) -> Optional[
@@ -619,6 +678,7 @@ def sync(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -633,13 +693,15 @@ def sync(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -652,19 +714,20 @@ def sync(
         project_id (str):
         location_id (UUID):
         method_id (UUID):
-        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDPUpdate',
-            'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate', 'MethodIWUpdate',
-            'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate', 'MethodRCDUpdate',
-            'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate', 'MethodRWSUpdate', 'MethodSAUpdate',
-            'MethodSPTUpdate', 'MethodSRSUpdate', 'MethodSRUpdate', 'MethodSSUpdate',
-            'MethodSVTUpdate', 'MethodTOTUpdate', 'MethodTPUpdate', 'MethodWSTUpdate']):
+        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDEFUpdate',
+            'MethodDPUpdate', 'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate',
+            'MethodIWUpdate', 'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate',
+            'MethodRCDUpdate', 'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate',
+            'MethodRWSUpdate', 'MethodSAUpdate', 'MethodSLBUpdate', 'MethodSPTUpdate',
+            'MethodSRSUpdate', 'MethodSSUpdate', 'MethodSTIUpdate', 'MethodSVTUpdate',
+            'MethodTOTUpdate', 'MethodTPUpdate', 'MethodTRUpdate', 'MethodWSTUpdate']):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]
+        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]
     """
 
     return sync_detailed(
@@ -686,6 +749,7 @@ async def asyncio_detailed(
         "MethodADUpdate",
         "MethodCDUpdate",
         "MethodCPTUpdate",
+        "MethodDEFUpdate",
         "MethodDPUpdate",
         "MethodDTUpdate",
         "MethodESAUpdate",
@@ -700,13 +764,15 @@ async def asyncio_detailed(
         "MethodRSUpdate",
         "MethodRWSUpdate",
         "MethodSAUpdate",
+        "MethodSLBUpdate",
         "MethodSPTUpdate",
         "MethodSRSUpdate",
-        "MethodSRUpdate",
         "MethodSSUpdate",
+        "MethodSTIUpdate",
         "MethodSVTUpdate",
         "MethodTOTUpdate",
         "MethodTPUpdate",
+        "MethodTRUpdate",
         "MethodWSTUpdate",
     ],
 ) -> Response[
@@ -716,6 +782,7 @@ async def asyncio_detailed(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -730,13 +797,15 @@ async def asyncio_detailed(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -749,19 +818,20 @@ async def asyncio_detailed(
         project_id (str):
         location_id (UUID):
         method_id (UUID):
-        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDPUpdate',
-            'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate', 'MethodIWUpdate',
-            'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate', 'MethodRCDUpdate',
-            'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate', 'MethodRWSUpdate', 'MethodSAUpdate',
-            'MethodSPTUpdate', 'MethodSRSUpdate', 'MethodSRUpdate', 'MethodSSUpdate',
-            'MethodSVTUpdate', 'MethodTOTUpdate', 'MethodTPUpdate', 'MethodWSTUpdate']):
+        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDEFUpdate',
+            'MethodDPUpdate', 'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate',
+            'MethodIWUpdate', 'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate',
+            'MethodRCDUpdate', 'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate',
+            'MethodRWSUpdate', 'MethodSAUpdate', 'MethodSLBUpdate', 'MethodSPTUpdate',
+            'MethodSRSUpdate', 'MethodSSUpdate', 'MethodSTIUpdate', 'MethodSVTUpdate',
+            'MethodTOTUpdate', 'MethodTPUpdate', 'MethodTRUpdate', 'MethodWSTUpdate']):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]]
+        Response[Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]]
     """
 
     kwargs = _get_kwargs(
@@ -786,6 +856,7 @@ async def asyncio(
         "MethodADUpdate",
         "MethodCDUpdate",
         "MethodCPTUpdate",
+        "MethodDEFUpdate",
         "MethodDPUpdate",
         "MethodDTUpdate",
         "MethodESAUpdate",
@@ -800,13 +871,15 @@ async def asyncio(
         "MethodRSUpdate",
         "MethodRWSUpdate",
         "MethodSAUpdate",
+        "MethodSLBUpdate",
         "MethodSPTUpdate",
         "MethodSRSUpdate",
-        "MethodSRUpdate",
         "MethodSSUpdate",
+        "MethodSTIUpdate",
         "MethodSVTUpdate",
         "MethodTOTUpdate",
         "MethodTPUpdate",
+        "MethodTRUpdate",
         "MethodWSTUpdate",
     ],
 ) -> Optional[
@@ -816,6 +889,7 @@ async def asyncio(
             "MethodAD",
             "MethodCD",
             "MethodCPT",
+            "MethodDEF",
             "MethodDP",
             "MethodDT",
             "MethodESA",
@@ -830,13 +904,15 @@ async def asyncio(
             "MethodRS",
             "MethodRWS",
             "MethodSA",
+            "MethodSLB",
             "MethodSPT",
-            "MethodSR",
             "MethodSRS",
             "MethodSS",
+            "MethodSTI",
             "MethodSVT",
             "MethodTOT",
             "MethodTP",
+            "MethodTR",
             "MethodWST",
         ],
     ]
@@ -849,19 +925,20 @@ async def asyncio(
         project_id (str):
         location_id (UUID):
         method_id (UUID):
-        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDPUpdate',
-            'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate', 'MethodIWUpdate',
-            'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate', 'MethodRCDUpdate',
-            'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate', 'MethodRWSUpdate', 'MethodSAUpdate',
-            'MethodSPTUpdate', 'MethodSRSUpdate', 'MethodSRUpdate', 'MethodSSUpdate',
-            'MethodSVTUpdate', 'MethodTOTUpdate', 'MethodTPUpdate', 'MethodWSTUpdate']):
+        body (Union['MethodADUpdate', 'MethodCDUpdate', 'MethodCPTUpdate', 'MethodDEFUpdate',
+            'MethodDPUpdate', 'MethodDTUpdate', 'MethodESAUpdate', 'MethodINCUpdate',
+            'MethodIWUpdate', 'MethodOTHERUpdate', 'MethodPTUpdate', 'MethodPZUpdate',
+            'MethodRCDUpdate', 'MethodROUpdate', 'MethodRPUpdate', 'MethodRSUpdate',
+            'MethodRWSUpdate', 'MethodSAUpdate', 'MethodSLBUpdate', 'MethodSPTUpdate',
+            'MethodSRSUpdate', 'MethodSSUpdate', 'MethodSTIUpdate', 'MethodSVTUpdate',
+            'MethodTOTUpdate', 'MethodTPUpdate', 'MethodTRUpdate', 'MethodWSTUpdate']):
 
     Raises:
         errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
         httpx.TimeoutException: If the request takes longer than Client.timeout.
 
     Returns:
-        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSPT', 'MethodSR', 'MethodSRS', 'MethodSS', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodWST']]
+        Union[HTTPValidationError, Union['MethodAD', 'MethodCD', 'MethodCPT', 'MethodDEF', 'MethodDP', 'MethodDT', 'MethodESA', 'MethodINC', 'MethodIW', 'MethodOTHER', 'MethodPT', 'MethodPZ', 'MethodRCD', 'MethodRO', 'MethodRP', 'MethodRS', 'MethodRWS', 'MethodSA', 'MethodSLB', 'MethodSPT', 'MethodSRS', 'MethodSS', 'MethodSTI', 'MethodSVT', 'MethodTOT', 'MethodTP', 'MethodTR', 'MethodWST']]
     """
 
     return (
